@@ -3,5 +3,5 @@ import sys
 from osism.main import main
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv[1:]))
