@@ -5,6 +5,7 @@ import subprocess
 
 # import ansible_runner
 from celery.signals import worker_process_init
+from loguru import logger
 from redis import Redis
 from pottery import Redlock
 
@@ -39,7 +40,10 @@ def celery_init_worker(**kwargs):
     redis = Redis(host="redis", port="6379")
 
 
-def run_ansible_in_environment(request_id, environment, role, arguments):
+def run_ansible_in_environment(
+    request_id, worker, environment, role, arguments, publish=True
+):
+    logger.info(f"worker = {worker}, environment = {environment}, role = {role}")
     result = ""
 
     if type(arguments) == list:
@@ -47,6 +51,8 @@ def run_ansible_in_environment(request_id, environment, role, arguments):
     else:
         joined_arguments = arguments
 
+    env = {"ENVIRONMENT": environment}
+
     # NOTE: Consider arguments in the future
     lock = Redlock(
         key=f"lock-ansible-{environment}-{role}",
@@ -57,8 +63,8 @@ def run_ansible_in_environment(request_id, environment, role, arguments):
     # NOTE: use python interface in the future, something with ansible-runner and the fact cache is
     #       not working out of the box
 
-    # execute roles from Kolla
-    if environment == "kolla":
+    # execute roles from kolla-ansible
+    if worker == "kolla-ansible":
         lock.acquire()
 
         if role == "mariadb_backup":
@@ -67,6 +73,7 @@ def run_ansible_in_environment(request_id, environment, role, arguments):
                 shell=True,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.STDOUT,
+                env=env,
             )
         else:
             p = subprocess.Popen(
@@ -74,20 +81,26 @@ def run_ansible_in_environment(request_id, environment, role, arguments):
                 shell=True,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.STDOUT,
+                env=env,
             )
 
-    # execute roles from Ceph
-    elif environment == "ceph":
+    # execute roles from ceph-ansible
+    elif worker == "ceph-ansible":
         lock.acquire()
         p = subprocess.Popen(
             f"/run.sh {role} {joined_arguments}",
             shell=True,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
+            env=env,
         )
 
     # execute the bifrost-command role
-    elif environment == "manager" and role == "bifrost-command":
+    elif (
+        worker == "osism-ansible"
+        and environment == "manager"
+        and role == "bifrost-command"
+    ):
         p = subprocess.Popen(
             f'/run-manager.sh bifrost-command "-e bifrost_arguments=\'{joined_arguments}\'" "-e bifrost_result_id={request_id}"',
             shell=True,
@@ -106,7 +119,11 @@ def run_ansible_in_environment(request_id, environment, role, arguments):
         )
 
     # process the bifrost-command result
-    if environment == "manager" and role == "bifrost-command":
+    if (
+        worker == "osism-ansible"
+        and environment == "manager"
+        and role == "bifrost-command"
+    ):
         p.wait()
 
         # Check for JSON result
@@ -124,13 +141,15 @@ def run_ansible_in_environment(request_id, environment, role, arguments):
     # process all other results
     else:
         for line in io.TextIOWrapper(p.stdout, encoding="utf-8"):
-            redis.publish(f"{request_id}", line)
+            if publish:
+                redis.publish(f"{request_id}", line)
             result += line
 
         rc = p.wait(timeout=60)
 
-        redis.publish(f"{request_id}", f"RC: {rc}\n")
-        redis.publish(f"{request_id}", "QUIT")
+        if publish:
+            redis.publish(f"{request_id}", f"RC: {rc}\n")
+            redis.publish(f"{request_id}", "QUIT")
 
         lock.release()
 
