@@ -3,13 +3,11 @@ import pynetbox
 from redis import Redis
 
 redis = Redis(host="redis", port="6379")
-nb = pynetbox.api(
-    settings.NETBOX_URL,
-    token=settings.NETBOX_TOKEN
-)
+nb = pynetbox.api(settings.NETBOX_URL, token=settings.NETBOX_TOKEN)
 
 if settings.IGNORE_SSL_ERRORS:
     import requests
+
     requests.packages.urllib3.disable_warnings()
     session = requests.Session()
     session.verify = False
